@@ -69,19 +69,57 @@ def debug_arg_with_diagnostics(arg):
 
 # This function unpacks the data we sent
 def deserialize_arg(arg_data):
-    if arg_data['type'] == 'data':
-        try:
-            # 1. Decode from base64
-            binary_data = base64.b64decode(arg_data['value'])
-            # 2. Decompress the data
-            decompressed = zlib.decompress(binary_data)
-            # 3. Unpickle to get original object
-            return pickle.loads(decompressed)
-        except Exception as e:
-            print(f"Error deserializing: {e}")
+    if isinstance(arg_data, dict) and 'type' in arg_data:
+        if arg_data['type'] == 'data' or arg_data['type'] == 'cloudpickle':
+            try:
+                # 1. Decode from base64
+                binary_data = base64.b64decode(arg_data['value'])
+                # 2. Decompress the data if needed
+                if arg_data['type'] == 'data':
+                    decompressed = zlib.decompress(binary_data)
+                else:
+                    decompressed = binary_data
+                # 3. Unpickle to get original object
+                obj = pickle.loads(decompressed)
+                
+                # Process astronomy data types
+                if isinstance(obj, dict):
+                    # Handle sparse catalog - return the dictionary as is
+                    # Don't try to convert to DataFrame here - just ensure the structure is correct
+                    if 'sources' in obj and 'positions' in obj and 'fluxes' in obj:
+                        print("Detected sparse catalog structure")
+                        print(f"sources type: {type(obj['sources'])}, positions type: {type(obj['positions'])}, fluxes type: {type(obj['fluxes'])}")
+                        print(f"sources length: {len(obj['sources'])}, positions shape: {getattr(obj['positions'], 'shape', 'unknown')}, fluxes length: {len(obj['fluxes'])}")
+                        # Let the function handle DataFrame creation
+                    
+                    # Handle ML model
+                    elif 'model' in obj and isinstance(obj['model'], bytes):
+                        print("Unpickling model from bytes")
+                        try:
+                            obj['model'] = pickle.loads(obj['model'])
+                            print(f"Unpickled model type: {type(obj['model'])}")
+                        except Exception as e:
+                            print(f"Error unpickling model: {e}")
+                            traceback.print_exc()
+                    
+                    # Handle HEALPix map
+                    elif 'pixels' in obj and 'pixel_values' not in obj:
+                        print("Adding pixel_values to HEALPix map")
+                        obj['pixel_values'] = obj['pixels']
+                
+                return obj
+            except Exception as e:
+                print(f"Error deserializing: {e}")
+                traceback.print_exc()
+                return arg_data['value']
+        elif arg_data['type'] == 'bytes_reference':
+            # ...existing code...
+        else:
             return arg_data['value']
+    elif isinstance(arg_data, dict) and "__nerd_data_reference" in arg_data:
+        # ...existing code...
     else:
-        return arg_data['value']
+        return arg_data
 
 # Debug function to get environment variables
 def debug_env():
