@@ -1,4 +1,11 @@
 # This template handles the argument unpacking and execution of the function
+# For astronomy functions, use patched versions
+try:
+    from catalog_patch import process_sparse_catalog as patched_sparse_catalog
+    print("Successfully imported patched sparse catalog function")
+except ImportError:
+    print("Patched sparse catalog function not available")
+    patched_sparse_catalog = None
 
 # Unpack all the arguments
 args = []
@@ -6,32 +13,22 @@ for arg_data in ARG_PLACEHOLDER:
     deserialized_arg = deserialize_arg(arg_data)
     
     # Apply diagnostics to log the argument details
-    # debug_arg_with_diagnostics is defined in cloud_template.py
     deserialized_arg = debug_arg_with_diagnostics(deserialized_arg)
     
     # Handle special cases for astronomy data
     if isinstance(deserialized_arg, dict):
-        # Case 1: Sparse catalog
+        # Handle special cases for astronomy data types
         if 'sources' in deserialized_arg and 'positions' in deserialized_arg and 'fluxes' in deserialized_arg:
             print("Processing sparse catalog before function call")
-            # No preprocessing needed - DataFrame creation happens in the function
-            
-        # Case 2: ML model
-        elif 'model' in deserialized_arg:
-            print("Processing ML model before function call")
-            # If the model is bytes, try to unpickle it
-            if isinstance(deserialized_arg['model'], bytes):
-                try:
-                    print("Unpickling model from bytes")
-                    deserialized_arg['model'] = pickle.loads(deserialized_arg['model'])
-                    print(f"Successfully unpickled model: {type(deserialized_arg['model'])}")
-                except Exception as e:
-                    print(f"Error unpickling model: {e}")
-        
-        # Case 3: HEALPix map
+        elif 'model' in deserialized_arg and isinstance(deserialized_arg['model'], bytes):
+            print("Unpickling model from bytes")
+            try:
+                deserialized_arg['model'] = pickle.loads(deserialized_arg['model'])
+                print(f"Successfully unpickled model of type: {type(deserialized_arg['model'])}")
+            except Exception as e:
+                print(f"Error unpickling model: {e}")
         elif 'pixels' in deserialized_arg:
             print("Processing HEALPix map before function call")
-            # Make sure we have pixel_values
             if 'pixel_values' not in deserialized_arg:
                 print("Adding pixel_values key with pixels data")
                 deserialized_arg['pixel_values'] = deserialized_arg['pixels']
@@ -42,15 +39,20 @@ for arg_data in ARG_PLACEHOLDER:
 kwargs = {}
 for key, arg_data in KWARGS_PLACEHOLDER.items():
     deserialized_arg = deserialize_arg(arg_data)
-    
-    # Apply diagnostics
     deserialized_arg = debug_arg_with_diagnostics(deserialized_arg)
-    
     kwargs[key] = deserialized_arg
 
 try:
     print(f"Starting cloud execution of FUNC_NAME_PLACEHOLDER...")
-    result = auto_reference_wrapper(FUNC_NAME_PLACEHOLDER, args, kwargs)
+    
+    # Check if we need to use patched version for specific functions
+    if FUNC_NAME_PLACEHOLDER == "process_sparse_catalog" and patched_sparse_catalog is not None:
+        print("Using patched version of process_sparse_catalog")
+        result = patched_sparse_catalog(*args, **kwargs)
+    else:
+        # Use the standard function
+        result = auto_reference_wrapper(FUNC_NAME_PLACEHOLDER, args, kwargs)
+    
     print(f"Function execution completed successfully")
 
     try:
